OPEN STREET SOUNDS - README (as of September 2014)
by Michael Macek - 0504524 - Vienna University of Technology - TU Wien
e0504524[at]student[dot]tuwien[dot]ac[dot]at


Open Street Sounds is an application which allows the user to browse through the map of Vienna and experience the sounds and noises of the city. 
The map is made up of tiles supported by OpenStreetMap in various zoom levels.
At any time, it is possible to place a pin with the left mouse button. Following a placement, the application will find informations about the surroundings and will play back fitting sounds.


Compile

Open up in Microsoft Visual Studio 2012 (Express), and compile...


Install (Binaries)

Install the visual c++ redistributional file "vcredist_x86.exe" from the folder "redist".
Install the OpenAL redistributional file "oalinst.exe" from the same folder.
Afterwards you can launch the programm by opening the OpenStreetSound.exe
First you will be asked to download a new XML file. Press OK and wait for a few minutes.


Controls

Hold LMB and drag - move map
LMB click - set Pin (load local information)
RMB click - remove Pin
Esc - Exit
F5  - refresh map


Limitations

First, while programming and planning I only looked at Vienna as the region of choice. It is hard-coded that only tiles in this area will be shown.
The effect of that is, that the longitude and latitude are seen as straight axes and used in a Cartesian coordinate system, which the earth clearly does not have.
If one could put the pin into the Atlantic Ocean at -48.19856/-16.37222 he would still hear the sounds of the Resselpark.

The OSM-XML file only stores nodes and ways. The detection of the surroundings can only be accomplished with nodes.
A way can be a line made up of multiple nodes or it can be an area. If the nodes that define that area (or line) are far apart and the detection area (hearing range) of the pin is too small to reach any of the nodes, it will simply not detect the area, whilst being in the middle of it.

To reduce the stress on the sound “hardware” and on the ears of the listener, the application has been limited to play a maximum of 8 different sounds.
If the pin would be placed in front of a church, which by definition of OSM is mapped as an way made out of multiple nodes, we wouldn’t only want to hear just 8 identical church bells.
Because of that, the applications only plays one sound source of a kind.
The penalty of that is, even when there are, for example, two tramway stations in the detection area, only the closer one will result in a sound source.

Underground objects like rivers are listed in the XML file. If the user should happen to place the pin at the Naschmarkt, the user will still hear the sound of a river, although it is clearly not audible in real life.

Furthermore a tramway can only be heard if the pin is close to a tramway stop.

Because of the way the Windows mouse click messages are handled, double click to zoom in is not implemented.
Usually Windows sends the mouse messages in this order: left mouse button down, then left mouse button up, then left mouse button double click and again left mouse button up. Because I intended to use a single left click to set the pin and start playing sounds, and also usually use the mouse wheel to zoom in map applications, I did not try and implement a zoom in via double click.


Used libraries

libxml - http://xmlsoft.org/ - http://www.zlatkovic.com/libxml.en.html
and its dependencies: iconv and zlib
for xml parsing

libcurl - http://curl.haxx.se/libcurl/
for downloading the open street maps tiles from the official servers
(server "b.tile.openstreetmap.org" is being used)

OpenAL - http://www.openal.org/
for playing audio files in a 3D environment.

freeALUT - https://github.com/vancegroup/freealut
free Audio Library Utility Toolkit for making life with OpenAL easier.

osmfilter.exe - http://wiki.openstreetmap.org/wiki/Osmfilter
for filtering an osm xml file. to make it smaller and therefore faster to look through


File structure

File OpenStreetSound.cpp - the main class which handles the window and the 
user input.
Namespace tools inherits all the other namespaces as well as the class Console,
which only loads in Debug mode, and displays a Console window with debug
information.
Namespace audio contains everything that has to do with creating sounds and
noises which the user will hear, whenever he sets the pin down. The most
important class in here is the OssStkManager class, which manages all the
different sounds and noises.
Namespace data handles the xml management. The main class is the OssXmlReader,
which parses the downloaded osm xml file and finds the information about the
surroundings out of that file.
Namespace visual contains everthing about the displaying the map, from
zooming and moving the map to downloading tiles. The most important class in
this namespace is OssMap

The folder "res" contains all the external resources:
folder "Sounds"
folder "Tiles" - contains all the locally stored tiles
"dl_parameters.txt" (neccessary) - a text file that contains the filter parameters
	for the	osmfilter.exe which is called whenever the application downloads a
	new xml	file which will afterwards be filtered automatically.
"osmfilter.exe" (neccessary) - an external program which is used to filter
	the downloaded osm xml file to remove overhead (i.e. tags that are not used
	from the programm and therefore will only slow the parsing down)
"overpass_api_query.txt" (neccessary) - the query the application will send to the
	overpass api to fetch an osm xml file of vienna with only nodes and ways 
	that include the tags we want to synthesize.
"default.png" (neccessary - in the folder Tiles) - the default tile, which will be shown, if no other
	tile was found, or if the user looks outside of the focused area
	
Used Sounds
"highway"="motorway” ­ http://www.freesound.org/people/schafferdavid/sounds/165017/
"highway"="primary” ­ see “motorway”
"highway"="secondary" ­ http://www.freesound.org/people/inchadney/sounds/173154/
"highway"="tertiary" ­ see “secondary”
"highway"="residential" ­http://www.freesound.org/people/OSH37/sounds/140820/
"highway"="pedestrian" ­ http://freesound.org/people/inchadney/sounds/149816/
"highway"="living_street" ­ see “residential”
"leisure"="playground" ­ http://freesound.org/people/foongaz/sounds/209901/
"leisure"="park" ­ http://www.freesound.org/people/pawsound/sounds/154835/
"leisure"="pitch" ­ http://www.freesound.org/people/tonant/sounds/237345/
“railway"="tram_stop" ­ http://www.freesound.org/people/notchfilter/sounds/43695/
"railway"="station" ­ http://freesound.org/people/inchadney/sounds/159465/
"amenity"="bus_station" ­ http://freesound.org/people/ninebilly/sounds/173006/
"amenity"="place_of_worship" ­ http://www.freesound.org/people/JarredGibb/sounds/219044/
“amenity”=”marketplace” ­ http://freesound.org/people/eckel/sounds/34615/
"waterway"="river" ­ http://www.freesound.org/people/Glaneur%20de%20sons/sounds/24511/
"natural"="water" ­ http://freesound.org/people/Owl/sounds/156525/
"power"="plant" ­ http://freesound.org/people/Zabuhailo/sounds/167673/
"power"="generator" ­ http://freesound.org/people/paulw2k/sounds/244420/
"landuse"="forest" ­ http://freesound.org/people/costaipsa/sounds/114021/
"landuse"="meadow" ­ http://freesound.org/people/inchadney/sounds/163617/ 
"landuse"="cemetary": “Music for Funeral Home ­ Part 11” from
http://incompetech.com/music/royalty­free/?keywords=funeral
"landuse"="vineyard" ­ http://freesound.org/people/FreqMan/sounds/24979/
"landuse"="industrial" ­ http://freesound.org/people/Micronin/sounds/184888/
"shop"="mall" ­ http://freesound.org/people/ultradust/sounds/160578/ and “Local Forecast ­
Elevator” from http://incompetech.com/music/royalty­free/index.html?genre=Jazz