/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef OSSMESSAGEBOXES_HPP_
#define OSSMESSAGEBOXES_HPP_

#include <stdio.h>
#include <Windows.h>
#include <string>

namespace openstreetsound {
	namespace tools {
		/*
		* Class OssMessageBoxes
		*
		* an object that has been found during the parsing of the xml file filtered.osm
		* stores information about OSM-Id, location, distance, angle and type 
		* gets called by the OsmXmlReader class
		*/
		class OssMessageBoxes {
		public:
			OssMessageBoxes();
			~OssMessageBoxes();

			/*
			createWindowFailed();

			MessageBox that will be called in the initialization of the application window
			*/
			void createWindowFailed();
			
			/*
			downloadXMLComplete(HWND hWnd)

			MessageBox that tells the user that the download of the xml file is complete
			*/
			void downloadXMLComplete(HWND hWnd);
			
			/*
			checkXMLFailed(HWND hWnd)

			MessageBox that tells the user, that no xml file is present.
			Returns the user selection.
			*/
			int checkXMLFailed(HWND hWnd);

			/*
			downloadTilesFailed(HWND hWnd)

			MessageBox that tells the user, that the bulk downloading of the missing tiles failed
			*/
			void downloadTilesFailed(HWND hWnd);

			/*
			about(HWND hWnd)

			MessageBox that shows information to the user.
			*/
			void about(HWND hWnd);

			/*
			help(HWND hWnd)

			MessageBox that shows the help
			*/
			void help(HWND hWnd);

			/*
			downloadXMLRequest(HWND hWnd)

			MessageBox that requests from the user a confirmation about downloading the xml file.
			Returns the user selection.
			*/
			int downloadXMLRequest(HWND hWnd);

			/*
			soundLoadingFailed(HWND hWnd)

			MessageBox that tells the user, that there has been a problem with playing sounds.
			*/
			void soundLoadingFailed(HWND hWnd, int error);


			/*
			showLicense(HWND hWnd)

			displays the GPL
			*/
			void showLicense(HWND hWnd);

			/*
			bulkDownloadTiles(HWND hWnd)

			if answered yes, this will allow downloading all the missing tiles.
			*/
			int bulkDownloadTiles(HWND hWnd);

			/*
			bulkDownloadTiles(HWND hWnd)

			notification message that downloading the tiles has finished.
			*/
			void bulkDownloadFinsihed(HWND hWnd, double time, int tiles);

		private:

		};
	}
}

#endif
