/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#include "OssXmlLoader.hpp"

using namespace openstreetsound::tools::data;

OssXmlLoader::OssXmlLoader() {
	server = "overpass.osm.rambler.ru/cgi/interpreter?data=";
}

OssXmlLoader::~OssXmlLoader() {

}

/* curl helper method */
size_t xml_write_data(void *ptr, size_t size, size_t nmemb, FILE *stream) {
    size_t written = fwrite(ptr, size, nmemb, stream);
    return written;
}

/* main method to download a osm xml file via the overpass api and libcurl */
void OssXmlLoader::download() {
	CURL *curl;
    FILE *fp;
    CURLcode res;
	/* path where to put the file */
	std::string filepath = ".\\res\\downloaded.osm";
	char outfilename[FILENAME_MAX];
	strcpy(outfilename, filepath.c_str());
    curl = curl_easy_init();
	#if _DEBUG
		printf("[OssXmlLoader::download()] %s%s\n", server.c_str(), readQuery().c_str());
	#endif
    if (curl) {
        fp = fopen(outfilename,"wb");
        curl_easy_setopt(curl, CURLOPT_URL, (server + readQuery()).c_str());
        curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, xml_write_data);
        curl_easy_setopt(curl, CURLOPT_WRITEDATA, fp);
        res = curl_easy_perform(curl);
        /* always cleanup */
        curl_easy_cleanup(curl);
        fclose(fp);
    }
}

/* filtering the downloaded.osm file with osmfilter.exe and a parameter file (to make it editable) */
void OssXmlLoader::filter() {
	#if _DEBUG
		printf("[OssXmlLoader::filter()] filtering downloaded.osm\n", server.c_str(), readQuery().c_str());
	#endif
	int retCode = system(".\\res\\osmfilter.exe .\\res\\downloaded.osm --parameter-file=.\\res\\dl_parameters.txt -o=.\\res\\filtered.osm");
}

/* deleting the downloaded xml file */
void OssXmlLoader::cleanup() {
	#if _DEBUG
		printf("[OssXmlLoader::cleanup()] deleting downloaded.osm\n", server.c_str(), readQuery().c_str());
	#endif
	if( remove( ".\\res\\downloaded.osm" ) != 0 ) {
		#if _DEBUG
			printf("[OssXmlLoader::cleanup()] Error deleting downloaded.osm\n", server.c_str(), readQuery().c_str());
		#endif
	}
}

/* reading the overpass api sql query file (to make the file editable) */
std::string OssXmlLoader::readQuery() {
	std::ifstream file(".//res//overpass_api_query.txt");
	std::string str;
	std::string file_contents;
	while (std::getline(file, str))
	{
	  file_contents += str;
	}  
	return file_contents;
}