/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#include "OssXmlResult.hpp"

using namespace openstreetsound::tools::data;

OssXmlResult::OssXmlResult(unsigned long inId, float inLon, float inLat, float inDistance) {
	id = inId;
	lon = inLon;
	lat = inLat;
	angle = 0;
	distance = inDistance;
	type = "void";

}

OssXmlResult::~OssXmlResult() {

}

/* result = atan2 (y,x) * 180 / PI; */
void OssXmlResult::calculateAngle(float centerLon, float centerLat){
	angle = atan2(centerLat - lat, centerLon - lon) * (180/3.14159265);
}

/* returns the node ID */
unsigned long OssXmlResult::getId() const{
	return id;
}

/* returns the calculated angle of the node in comparison to the marked point */
float OssXmlResult::getAngle(){
	return angle;
}

/* returns the calculated distance of the node in comparison to the marked point */
float OssXmlResult::getDinstance(){
	return distance;
}

/* returns the longitude of the point */
float OssXmlResult::getLon(){
	return lon;
}

/* returns the latitude of the point */
float OssXmlResult::getLat(){
	return lat;
}

/* sets the type of the node which is found by a tag most often in the ways section of the osm xml */
void OssXmlResult::setType(std::string inType){
	type = inType;
}

/* returns the type of the point */
std::string OssXmlResult::getType(){
	return type;
}

/* used by std::find */
bool OssXmlResult::operator== (const OssXmlResult &oxr){
	if (this->id == oxr.id) {
		return true;
	} else {
		return false;
	}
}

/* returns a neatly formatted string */
std::string OssXmlResult::toString() {
	char buffer[120];
	sprintf (buffer, "id: %u @ %3.4f : %3.4f dist %1.3f type %s", id, lon, lat, distance, type.c_str());
	return std::string(buffer);
}