/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef OSSPIN_HPP_
#define OSSPIN_HPP_

/* STL & Windows headers */
#include <windows.h>
#include <string>

/* won headers */
#include "OssPoint.hpp"

namespace openstreetsound {
	namespace tools {
		namespace visual {
			/*
			Class OssPin
			
			class for the pin which is "stuck" into the map when the user left clicks
			*/
			class OssPin {
				public: 
					/*
					Constructor
					
					initializes the private variables and sets the values
					size of the icon
					offset to the middle of the lower edge
					(where the needle pins the map)
					location in window coordinates
					visibility boolean of the pin
					loading the picture handle
					*/
					OssPin();

					/*
					Deconstructor
					
					deletes the icon handle
					*/
					~OssPin();

					/*
					setLocation(int x, int y)
					Input: integer x and y
					
					sets the location in window coordinates 
					*/
					void setLocation(int x, int y);

					/*
					setLongLat(double lo, double la)
					Input: double longitude and latitude
					
					sets the longitude and latitude 
					*/
					void setLongLat(double lo, double la);

					/*
					getVisibility()
					
					returns the boolean flag if the pin is visible 
					*/
					bool getVisibility();

					/*
					setVisibility()
					
					sets the boolean flag "visible" true (visible)
					*/
					void setVisible();

					/*
					setInvisibility()
					
					sets the boolean flag "visible" false (invisible)
					*/
					void setInvisible();

					/*
					draw(HDC hdc)
					
					Input: handle for Graphics Device
					draws the icon with standard winapi functions onto given window (hdc)
					*/
					void draw(HDC hdc);

					/*
					getLocation()
					
					returns the location in window coordinates 
					*/
					OssPoint getLocation();

					/*
					std::pair<double, double> getLongLat()
					
					makes a std:pair and returns both the longitude and latitude
					*/
					std::pair<double, double> getLongLat();

					/*
					getLongitude();
					
					returns the double longitude
					*/
					double getLongitude();

					/*
					getLatitude();
					
					returns the double latitude
					*/
					double getLatitude();

					/*
					moveLocation(const OssPoint &p);
					
					adds a movement point to the location point
					*/
					void moveLocation(const OssPoint &p);

				private:
					/*
					int offsetX
					 
					-(sizeX/2) so that the point the pin pins
					is on the same X as the peak of the needle
					*/ 
					int offsetX;

					/*
					int offsetY
					 
					-sizeY so that the pin is over the point
					*/ 
					int offsetY;

					/*
					int sizeX
					 
					the size in pixels of x of the icon
					*/ 
					int sizeX;

					/*
					int sizeY
					 
					the size in pixels of y of the icon
					*/ 
					int sizeY;

					/*
					location
					 
					the size in pixels of x of the icon
					*/ 
					OssPoint location;

					/*
					double longitude
					 
					the longitude of the point where the pins is stuck into
					*/ 
					double longitude;

					/*
					double latitude
					 
					the latitude of the point where the pins is stuck into
					*/ 
					double latitude;

					/*
					boolean visible
					 
					flag if the pin is visible (will be drawn) or not
					*/ 
					bool visible;

					/*
					HICON pIco
					 
					handle of the stores icon file
					*/ 
					HICON pIco;
			};
		}
	}
}

#endif