/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#include "OssPoint.hpp"

using namespace openstreetsound::tools::visual;

/* standard constructor */
OssPoint::OssPoint() {
	this->x = 0;
	this->y = 0;
}

/* custom constructor */
OssPoint::OssPoint(int _x, int _y) {
	this->x = _x;
	this->y = _y;
}

/* copy constructor */
OssPoint::OssPoint(OssPoint &p) {
	this->x = p.x;
	this->y = p.y;
}

OssPoint OssPoint::operator+ (const OssPoint &p) {
	OssPoint result;
	result.x = this->x + p.x;
	result.y = this->y + p.y;
	return result;
}

OssPoint OssPoint::operator- (const OssPoint &p) {
	OssPoint result;
	result.x = this->x - p.x;
	result.y = this->y - p.y;
	return result;
}

OssPoint OssPoint::operator* (const OssPoint &p) {
	OssPoint result;
	result.x = this->x * p.x;
	result.y = this->y * p.y;
	return result;
}

OssPoint OssPoint::operator/ (const OssPoint &p) {
	OssPoint result;
	result.x = this->x / p.x;
	result.y = this->y / p.y;
	return result;
}

void OssPoint::operator+= (const OssPoint &p) {
	x += p.x;
	y += p.y;
}

void OssPoint::operator-= (const OssPoint &p){
	x -= p.x;
	y -= p.y;
}

void OssPoint::operator*= (const OssPoint &p){
	x *= p.x;
	y *= p.y;
}

void OssPoint::operator/= (const OssPoint &p){
	x /= p.x;
	y /= p.y;
}

OssPoint OssPoint::operator+ (int a) {
	OssPoint result;
	result.x = this->x + a;
	result.y = this->y + a;
	return result;
}

OssPoint OssPoint::operator- (int a) {
	OssPoint result;
	result.x = this->x - a;
	result.y = this->y - a;
	return result;
}

OssPoint OssPoint::operator* (int a) {
	OssPoint result;
	result.x = this->x * a;
	result.y = this->y * a;
	return result;
}

OssPoint OssPoint::operator/ (int a) {
	OssPoint result;
	result.x = this->x / a;
	result.y = this->y / a;
	return result;
}

void OssPoint::operator+= (int a) {
	x += a;
	y += a;
}

void OssPoint::operator-= (int a) {
	x -= a;
	y -= a;
}

void OssPoint::operator*= (int a) {
	x *= a;
	y *= a;
}

void OssPoint::operator/= (int a) {
	x /= a;
	y /= a;
}

void OssPoint::set(int nx, int ny) {
	x = nx;
	y = ny;
}

void OssPoint::set(OssPoint &p) {
	this->x = p.x;
	this->y = p.y;
}

void OssPoint::setX(int nx) {
	this->x = nx;
}

void OssPoint::setY(int ny) {
	this->y = ny;
}

bool OssPoint::operator> (const OssPoint &p) {
	if (this->x > p.x && this->y > p.y) {
		return true;
	} else {
		return false;
	}
}

bool OssPoint::operator< (const OssPoint &p) {
	if (this->x < p.x && this->y < p.y) {
		return true;
	} else {
		return false;
	}
}

bool OssPoint::operator== (const OssPoint &p) {
	if (this->x == p.x && this->y == p.y) {
		return true;
	} else {
		return false;
	}
}

/* checks if itself is between the given OssPoints by comparing the values */
bool OssPoint::inBetween(const OssPoint &tl, const OssPoint &br) {
	if (this->x > tl.x && this->y > tl.y && this->x < br.x && this->y < br.y) {
		return true;
	} else {
		return false;
	}
}

int OssPoint::getX() {
	return x;
}

int OssPoint::getY() {
	return y;
}