/*

    This file is part of OpenStreetSounds.

    OpenStreetSounds is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenStreetSounds is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with OpenStreetSounds. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef OSSPOINT_HPP_
#define	OSSPOINT_HPP_

namespace openstreetsound {
	namespace tools {
		namespace visual {
		class OssPoint {
			public: 
				/*
				Constructor
				
				creates a simple point with x = y = 0
				*/
				OssPoint();

				/*
				Constructor
				
				creates a simple point with given values for x and y
				*/
				OssPoint(int _x, int _y);
				
				/*
				Copy Constructor
				
				creates a deep copy of the given point
				*/
				OssPoint(OssPoint &p);

				/*
				operator+
				Input another point
				
				returns a point with
				the sum of this and the other points x values for its x
				and the sum of this and the other points y values for its y
				*/
				OssPoint operator+ (const OssPoint &p);

				/*
				operator-

				Input another point
				
				returns a point with
				the difference of this and the other points x values for its x
				and the difference of this and the other points y values for its y
				*/
				OssPoint operator- (const OssPoint &p);

				/*
				operator*

				Input another point
				
				returns a point with
				the product of this and the other points x values for its x
				and the product of this and the other points y values for its y
				*/
				OssPoint operator* (const OssPoint &p);

				/*
				operator*
				
				Input another point
				
				returns a point with
				the quotient of this and the other points x values for its x
				and the quotient of this and the other points y values for its y
				*/
				OssPoint operator/ (const OssPoint &p);

				/*
				operator+=

				Input another point
				
				adds the x and y values of the other point
				to its own x and y values, respectively
				*/
				void operator+= (const OssPoint &p);

				/*
				operator-=
				
				Input another point
				
				subtracts the x and y values of the other point
				to its own x and y values, respectively
				*/
				void operator-= (const OssPoint &p);

				/*
				operator*=
				
				Input another point
				
				multiplies the x and y values of the other point
				to its own x and y values, respectively
				*/
				void operator*= (const OssPoint &p);

				/*
				operator/=
				
				Input another point
				
				divides the x and y values of the other point
				to its own x and y values, respectively
				*/
				void operator/= (const OssPoint &p);

				/*
				operator+
				
				Input an integer
				
				returns a new point by adding the input to both the x and the y value
				*/
				OssPoint operator+ (int a);

				/*
				operator-
				
				Input an integer
				
				returns a new point by subtracting the input from both the x and the y value
				*/
				OssPoint operator- (int a);

				/*
				operator*
				
				Input an integer

				returns a new point by multipling the input to both the x and the y value
				*/
				OssPoint operator* (int a);

				/*
				operator/
				
				Input an integer
				
				returns a new point by dividing both the x and the y value by the input
				*/
				OssPoint operator/ (int a);

				/*
				operator+
				
				Input an integer
				
				adds the input to both the x and the y value
				*/
				void operator+= (int a);

				/*
				operator-
				
				Input an integer
				
				subtracts the input from both the x and the y value
				*/
				void operator-= (int a);

				/*
				operator*
				
				Input an integer
				
				multiplies the input to both the x and the y value
				*/
				void operator*= (int a);

				/*
				operator/
				
				Input an integer
				
				divides both the x and the y value by the input
				*/
				void operator/= (int a);

				/*
				operator>
				
				Input an integer
				
				compares the point with the input
				returns true only if both x and y are bigger
				*/
				bool operator> (const OssPoint &p);

				/*
				operator<
				
				Input an integer
				
				compares the point with the input
				returns true only if both x and y are smaller
				*/
				bool operator< (const OssPoint &p);

				/*
				operator==
				
				Input an integer
				
				compares the point with the input
				returns true only if both x and y are equal
				*/
				bool operator== (const OssPoint &p);

				/*
				set(int nx, int ny)
				
				Input integer nx and ny
				
				replaces its x value with nx and y with ny
				*/
				void set(int nx, int ny);

				/*
				set(OssPoint &p)
				
				Input OssPoint p (Reference)
				
				replaces its x and y values with the ones of &p
				*/
				void set(OssPoint &p);

				/*
				set(int nx)
				
				Input integer nx
				
				replaces its x value with nx
				*/
				void setX(int nx);

				/*
				set(int ny)
				
				Input integer ny
				
				replaces its y with ny
				*/
				void setY(int ny);

				/*
				inBetween(const OssPoint &tl, const OssPoint &br)
				
				Input OssPoint tl and br (both References)
				tl = top left, br = bottom right
				
				checks if the point is inbetween the given ones
				returns true if it is
				*/
				bool inBetween(const OssPoint &tl, const OssPoint &br);

				/*
				getX()
				
				returns the interger of x
				*/
				int getX();

				/*
				getY()
				
				returns the interger of y
				*/
				int getY();

			private: 
				/* stores the value of x */
				int x;

				/* stores the value of y */
				int y;

			};
		}
	}
}

#endif